package com.ruoyi.ss.menuRole.service;

import com.ruoyi.ss.menuRole.domain.MenuRole;
import com.ruoyi.ss.menuRole.domain.MenuRoleQuery;
import com.ruoyi.ss.menuRole.domain.MenuRoleVO;

import java.util.List;

/**
 * 角色和菜单关联Service接口
 *
 * @author qzz
 * @date 2025-01-16
 */
public interface IMenuRoleService
{
    /**
     * 查询角色和菜单关联
     *
     * @param roleId 角色和菜单关联主键
     * @return 角色和菜单关联
     */
    public MenuRoleVO selectMenuRoleByRoleId(String roleId);

    /**
     * 查询角色和菜单关联列表
     *
     * @param menuRole 角色和菜单关联
     * @return 角色和菜单关联集合
     */
    public List<MenuRoleVO> selectMenuRoleList(MenuRoleQuery menuRole);

    /**
     * 新增角色和菜单关联
     *
     * @param menuRole 角色和菜单关联
     * @return 结果
     */
    public int insertMenuRole(MenuRole menuRole);

    /**
     * 修改角色和菜单关联
     *
     * @param menuRole 角色和菜单关联
     * @return 结果
     */
    public int updateMenuRole(MenuRole menuRole);

    /**
     * 批量删除角色和菜单关联
     *
     * @param roleIds 需要删除的角色和菜单关联主键集合
     * @return 结果
     */
    public int deleteMenuRoleByRoleIds(String[] roleIds);

    /**
     * 删除角色和菜单关联信息
     *
     * @param roleId 角色和菜单关联主键
     * @return 结果
     */
    public int deleteMenuRoleByRoleId(String roleId);
}
